@@ -85,25 +85,30 @@ def parse_mark(mark, default_date, config):
 
     try:
         parts = re.findall(RE_PARSING, mark)[0]
-        if parts[1] and parts[2]:
-            begin_date = datetime.date(int(parts[1]), int(parts[2]), int(parts[3]) or 1)
+        if parts[2] and parts[3]:
+            day = int(parts[4]) if parts[4] != '' else 1
+            begin_date = datetime.date(int(parts[2]), int(parts[3]), day)
         else:
             begin_date = default_date
 
-        if parts[0]:
-            duration = parse_length(parts[0])
+        duration_multiplier = int(parts[0]) if parts[0] != '' else 1
+        if parts[1]:
+            duration = parse_length(parts[1])
         else:
             duration = parse_length(config['default_duration'])
+        duration *= duration_multiplier
 
         try:
             begin_date + duration
         except OverflowError:
             duration = relativedelta(days=(datetime.datetime(datetime.MAXYEAR, 12, 31).date() - begin_date).days)
 
-        if parts[4]:
-            step = parse_length(parts[4])
+        step_multiplier = int(parts[5]) if parts[5] != '' else 1
+        if parts[6]:
+            step = parse_length(parts[6])
         else:
             step = parse_length(config['default_step'])
+        step *= step_multiplier
 
     except Exception as e:
         # TODO: Error handling
@@ -116,9 +121,37 @@ def parse_mark(mark, default_date, config):
     return begin_date, duration, step
 
 
-# Infer Duration, start and steps. Spacing optinonal. Format: [123|KEYWORD] [@ YYYY-MM[-DD]] [/ step]
-# 0. max duration, 1. year, 2. month, 3. day, 4. min step
-RE_PARSING = re.compile(r"^\s*?([^-/\s]+)?\s*?(?:@\s*?([0-9]{4})-([0-9]{2})(?:-([0-9]{2}))?)?\s*?(?:\/\s*?([^-/\s]+)?\s*?)?$")
+# Infer Duration, start and steps. Spacing optional.
+# Format: [x] [period] [@ YYYY-MM[-DD]] [/ [m] step]
+# x: period multiplier or number of days
+# period: keyword ('day[s]', 'week[s]', 'month[s]', 'year[s]')
+# YYYY-MM-DD: start date
+# m: multiplier for step size
+# step: step size with either the number of days or a keyword
+# (see period)
+RE_PARSING = re.compile((
+    # Match 'x' but only if there does not follow @, / or end of line as then we have
+    # to match it to 'period'. If we combine 'x' with 'period' there has to be a space
+    # or letter following, which is ensured by '(?=[\sa-zA-Z]+)'. It basically looks
+    # for a 'digit boundary'.
+    r"^\s*([0-9]+(?=[\sa-zA-Z]+)(?!\s*[@$/]))?"
+
+    # Match 'period' to be anything except '-', '/' or whitespace.
+    r"\s*([^-/\s]+)?"
+
+    # Look for an @ and the following start date specification.
+    # Specifying the date is optional.
+    r"\s*(?:@\s*([0-9]{4})-([0-9]{2})(?:-([0-9]{2}))?)?"
+
+    # Look for an '/' which might be followed by a step size multiplicator
+    # and step size.
+    # Only match the multiplicator if there is a step size (as number or keyword)
+    # following. Otherwise this number has to be matched as the step size itself.
+    # Works similar to the regex for 'x' and 'period'.
+    r"\s*(?:\/\s*([0-9]+(?=[\sa-zA-Z])(?!\s*$))?\s*([^-/\s]+)?\s*)?$"
+))
+
+
 def distribute_over_period(params, default_date, total_value, config):
     """
     Distribute value over points in time.
@@ -143,6 +176,11 @@ def distribute_over_period(params, default_date, total_value, config):
     amounts = []
     accumulated_remainder = D(str(0))
 
+    # TODO: In the following `begin_date + i * step` can result in an OverflowError
+    # If 'begin_date + i * step' is already close to the maximum date that a 'datetime'
+    # object can hold but still fulfilling the while condition, then
+    # 'begin_date + (i + 1) * step' might lead to an OverflowError because it exceeds
+    # the maximum possible date which can be hold by a 'datetime' object.
     i = 0
     end_date = begin_date + duration
     today_date = datetime.date.today()
@@ -157,6 +195,13 @@ def distribute_over_period(params, default_date, total_value, config):
         i += 1
         tmp_date = begin_date + i * step
 
+    if sum(amounts) != total_value:
+        if len(amounts) == 0:
+            amounts.append(D(str(total_value)))
+            dates.append(begin_date)
+        else:
+            amounts[-1] += (total_value - sum(amounts))
+
     return (dates, amounts)
 
 
@@ -180,9 +225,13 @@ def parse_length(int_or_string):
         ).days
         dictionary = {
             'day': relativedelta(days=+1),
+            'days': relativedelta(days=+1),
             'week': relativedelta(weeks=+1),
+            'weeks': relativedelta(weeks=+1),
             'month': relativedelta(months=+1),
+            'months': relativedelta(months=+1),
             'year': relativedelta(years=+1),
+            'years': relativedelta(years=+1),
             'inf': relativedelta(days=+max_days),
             'infinite': relativedelta(days=+max_days),
             'max': relativedelta(days=+max_days)
